<?php
namespace Keizer\KoningInstagram\Controller;

use Keizer\KoningInstagram\Utility\ConfigurationUtility;

/**
 * Frontend Controller: Content
 *
 * @package Keizer\KoningInstagram\Controller
 */
class ContentController extends AbstractActionController
{
    /**
     * Action: Show media with configured credentials
     *
     * @return void
     */
    public function showAction()
    {
        if (!isset($this->settings['data']['credential']) || !ConfigurationUtility::isValid()) {
            $this->view->assign('invalidConfiguration', true);
        } else {
            $credential = $this->getCredentialRepository()->findByUid($this->settings['data']['credential']);
            if ($credential !== null) {
                /** @var \Keizer\KoningInstagram\Domain\Model\Credential $credential */
                try {
                    $request = $this->getClient()->request('GET',
                        $this->getInstagramSetting('baseUrl') . 'v1/tags/' . $this->settings['data']['tags'] . '/media/recent',
                        array(
                            'query' => array(
                                'access_token' => $credential->getAccessToken(),
                                'count' => $this->settings['data']['limit']
                            )
                        ));
                    $response = json_decode($request->getBody(), true);

                    if (is_array($response) && isset($response['data'])) {
                        $this->view->assignMultiple([
                            'data' => $response['data'],
                            'contentObject' => $this->configurationManager->getContentObject()->data
                        ]);
                    }
                } catch (\GuzzleHttp\Exception\ClientException $e) {
                    $this->view->assign('error', true);
                }
            } else {
                $this->view->assign('invalidConfiguration', true);
            }
        }
    }

    /**
     * Action: Show user content from configured credentials
     *
     * @return void
     */
    public function userAction()
    {
        if (!isset($this->settings['data']['credential']) || !ConfigurationUtility::isValid()) {
            $this->view->assign('invalidConfiguration', true);
        } else {
            $credential = $this->getCredentialRepository()->findByUid($this->settings['data']['credential']);
            if ($credential !== null) {
                /** @var \Keizer\KoningInstagram\Domain\Model\Credential $credential */
                try {
                    $request = $this->getClient()->request('GET',
                        $this->getInstagramSetting('baseUrl') . 'v1/users/self/media/recent',
                        array(
                            'query' => array(
                                'access_token' => $credential->getAccessToken(),
                                'count' => $this->settings['data']['limit']
                            )
                        ));
                    $response = json_decode($request->getBody(), true);

                    if (is_array($response) && isset($response['data'])) {
                        $this->view->assignMultiple([
                            'data' => $response['data'],
                            'contentObject' => $this->configurationManager->getContentObject()->data
                        ]);
                    }
                } catch (\GuzzleHttp\Exception\ClientException $e) {
                    $this->view->assign('error', true);
                }
            } else {
                $this->view->assign('invalidConfiguration', true);
            }
        }
    }
}
